Author: Shao Mengjie at 20220803

Email: xiaotinghua@zju.edu.cn

institute: Key laboratory of Microbiol technology and Bioinformatics of Zhejiang Province

This program is designed for annotation of antimicrobal resistance(AMR), pdif site and pdif-ARGs module in bacteria.

PdifFinder is a python3.X script, running on linux. You can download from github by git clone https://github.com/mjshao06/pdifFinder.git.
